@@ -18,7 +18,7 @@ Subfield names:
 
 For example:
 
-   has 'duration' => ( type => 'Compound' );
+   has 'duration' => ( type => 'Duration' );
    has 'duration.hours' => ( type => 'Int', range_start => 0,
         range_end => 23 );
    has 'duration.minutes' => ( type => 'Int', range_start => 0,
@@ -33,7 +33,7 @@ sub validate {
     my @dur_parms;
     foreach my $child ( $self->all_fields ) {
         unless ( $child->value =~ /^\d+$/ ) {
-            $self->add_error( "Invalid value for " . $self->label . " " . $child->label );
+            $self->add_error( "Invalid value for [1_] [2_]", $self->loc_label, $child->loc_label );
             next;
         }
         push @dur_parms, ( $child->accessor => $child->value );
