@@ -1,6 +1,7 @@
 package HTML::FormHandler::Widget::Field::CheckboxGroup;
 
 use Moose::Role;
+use namespace::autoclean;
 
 with 'HTML::FormHandler::Widget::Field::Role::SelectedOption';
 with 'HTML::FormHandler::Widget::Field::Role::HTMLAttributes';
@@ -9,14 +10,17 @@ has 'input_without_param' => ( is => 'ro', default => sub {[]} );
 has 'not_nullable' => ( is => 'ro', default => 1 );
 
 sub render {
-    my ( $self, $result ) = @_;
-
-    $result ||= $self->result;
+    my $self = shift;
+    my $result = shift || $self->result;
     my $output = " <br />";
     my $index  = 0;
+    my $id = $self->id;
+    my $html_attributes = $self->_add_html_attributes;	# does that make sense?
+
     foreach my $option ( @{ $self->options } ) {
-        $output .= '<input type="checkbox" value="' . $option->{value} . '"';
-        $output .= ' name="' . $self->html_name . '" id="' . $self->id . ".$index\"";
+        $output .= '<input type="checkbox" value="'
+            . $self->html_filter($option->{value}) . '" name="'
+            . $self->html_name . qq{" id="$id.$index"};
         if ( my $ffif = $result->fif ) {
             if ( $self->multiple == 1 ) {
                 my @fif;
@@ -38,13 +42,12 @@ sub render {
         }
         $output .= ' checked="checked"'
             if $self->check_selected_option($option);
-        $output .= $self->_add_html_attributes;
+        $output .= $html_attributes;
         $output .= ' />';
-        $output .= $option->{label} . '<br />';
+        $output .= $self->html_filter($option->{label}) . '<br />';
         $index++;
     }
     return $self->wrap_field( $result, $output );
 }
 
-use namespace::autoclean;
 1;
