@@ -1,29 +1,34 @@
 package HTML::FormHandler::Widget::Field::Select;
 
 use Moose::Role;
+use namespace::autoclean;
 
 with 'HTML::FormHandler::Widget::Field::Role::SelectedOption';
 with 'HTML::FormHandler::Widget::Field::Role::HTMLAttributes';
 
 sub render {
-    my ( $self, $result ) = @_;
+    my $self = shift;
+    my $result = shift || $self->result;
+    my $id = $self->id;
+    my $index = 0;
+    my $multiple = $self->multiple;
+    my $output = '<select name="' . $self->html_name . qq{" id="$id"};
+    my $t;
 
-    $result ||= $self->result;
-    my $output = '<select name="' . $self->html_name . '"';
-    $output .= ' id="' . $self->id . '"';
-    $output .= ' multiple="multiple"' if $self->multiple == 1;
-    $output .= ' size="' . $self->size . '"' if $self->size;
+    $output .= ' multiple="multiple"' if $multiple;
+    $output .= qq{ size="$t"} if $t = $self->size;
     $output .= $self->_add_html_attributes;
     $output .= '>';
-    my $index = 0;
-    if( $self->empty_select ) {
-        $output .= '<option value="">' . $self->empty_select . '</option>'; 
-    }
+
+    $t = $self->empty_select
+        and $output .= qq{<option value="">$t</option>};
+
     foreach my $option ( @{ $self->{options} } ) {
-        $output .= '<option value="' . $option->{value} . '" ';
-        $output .= 'id="' . $self->id . ".$index\" ";
-        if ( my $ffif = $self->html_filter($result->fif) ) {
-            if ( $self->multiple == 1 ) {
+        $output .= '<option value="'
+            . $self->html_filter($option->{value})
+            . qq{" id="$id.$index"};
+        if ( my $ffif = $result->fif ) {
+            if ( $multiple ) {
                 my @fif;
                 if ( ref $ffif ) {
                     @fif = @{$ffif};
@@ -32,23 +37,22 @@ sub render {
                     @fif = ($ffif);
                 }
                 foreach my $optval (@fif) {
-                    $output .= 'selected="selected"'
+                    $output .= ' selected="selected"'
                         if $self->check_selected_option($option, $optval);
                 }
             }
             else {
-                $output .= 'selected="selected"'
+                $output .= ' selected="selected"'
                     if $self->check_selected_option($option, $ffif);
             }
         }
-        $output .= 'selected="selected"'
+        $output .= ' selected="selected"'
             if $self->check_selected_option($option);
-        $output .= '>' . $option->{label} . '</option>';
+        $output .= '>' . $self->html_filter($option->{label}) . '</option>';
         $index++;
     }
     $output .= '</select>';
     return $self->wrap_field( $result, $output );
 }
 
-use namespace::autoclean;
 1;
